# python-iap

[![CircleCI](https://circleci.com/gh/educreations/python-iap.svg?style=svg)](https://circleci.com/gh/educreations/python-iap) [![PyPI version](https://badge.fury.io/py/iap.svg)](https://badge.fury.io/py/iap)

Python utilities for working with Apple In-App Purchases (IAP)

## Copyright

Copyright © 2019, Educreations, Inc under the MIT software license. See LICENSE for more information.
